/**
 *******************************************************************************
 * @file    tmpm3Vx_dnf.c
 * @brief   This file provides API functions for DNF driver.
 * @version V2.0.2.1
 * @date    2015/06/26
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "tmpm3Vx_dnf.h"

#if defined(__TMPM3Vx_DNF_H)
/** @addtogroup TX03_Periph_Driver
  * @{
  */

/** @defgroup DNF 
  * @brief DNF driver modules
  * @{
  */
/** @defgroup DNF_Private_Defines
  * @{
  */

/** @} */
/* End of group DNF_Private_Defines */

/** @defgroup DNF_Private_FunctionPrototypes
  * @{
  */

/** @} */
/* End of group DNF_Private_FunctionPrototypes */

/** @defgroup DNF_Private_Functions
  * @{
  */

/** @} */
/* End of group group DNF_Private_Functions */

/** @defgroup DNF_Exported_Functions
  * @{
  */

/**
  * @brief  Select noise filter clock.
  * @param  FilterClk: Noise filter clock.
  *   This parameter can be one of the following values:
  *   DNF_FILTER_CLK_STOP, DNF_FILTER_CLK_FSYS_2, DNF_FILTER_CLK_FSYS_4,
  *   DNF_FILTER_CLK_FSYS_8, DNF_FILTER_CLK_FSYS_16, DNF_FILTER_CLK_FSYS_32,
  *   DNF_FILTER_CLK_FSYS_64 or DNF_FILTER_CLK_FSYS_128.
  * @retval None
  * @register The used register:
  *   NFCKCR<NFCKS[2:0]>
  */
void DNF_SetFilterClk(uint32_t FilterClk)
{
    /* Check the parameters */
    assert_param(IS_DNF_FILTER_CLK(FilterClk));

    TSB_NF->CKCR = FilterClk;
    while (TSB_NF->CKCR != FilterClk) {
      /* Wait for updating CKCR */
    }
}

/**
  * @brief  Get noise filter clock.
  * @param  None
  * @retval Noise filter clock
  *   The value returned can be one of the following values:
  *   DNF_FILTER_CLK_STOP, DNF_FILTER_CLK_FSYS_2, DNF_FILTER_CLK_FSYS_4,
  *   DNF_FILTER_CLK_FSYS_8, DNF_FILTER_CLK_FSYS_16, DNF_FILTER_CLK_FSYS_32,
  *   DNF_FILTER_CLK_FSYS_64 or DNF_FILTER_CLK_FSYS_128.
  * @register The used register:
  *   NFCKCR<NFCKS[2:0]>
  */
uint32_t DNF_GetFilterClk(void)
{
    uint32_t retval = TSB_NF->CKCR;

    return retval;
}

/**
  * @brief  Enable or disable the INT0 noise filter. 
  * @param  NewState: The INT0 noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFEN0>
  */
void DNF_SetInt0Filter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFEN0 = 1U;
    } else {
        TSB_NF_ENCR_NFEN0 = 0U;
    }
}

/**
  * @brief  Get the INT0 noise filter state. 
  * @param  None
  * @retval The INT0 noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFEN0>
  */
FunctionalState DNF_GetInt0FilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFEN0 == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

/**
  * @brief  Enable or disable the INT1 noise filter. 
  * @param  NewState: The INT1 noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFEN1>
  */
void DNF_SetInt1Filter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFEN1 = 1U;
    } else {
        TSB_NF_ENCR_NFEN1 = 0U;
    }
}

/**
  * @brief  Get the INT1 noise filter state. 
  * @param  None
  * @retval The INT1 noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFEN1>
  */
FunctionalState DNF_GetInt1FilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFEN1 == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

/**
  * @brief  Enable or disable the INT2 noise filter. 
  * @param  NewState: The INT2 noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFEN2>
  */
void DNF_SetInt2Filter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFEN2 = 1U;
    } else {
        TSB_NF_ENCR_NFEN2 = 0U;
    }
}

/**
  * @brief  Get the INT2 noise filter state. 
  * @param  None
  * @retval The INT2 noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFEN2>
  */
FunctionalState DNF_GetInt2FilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFEN2 == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

/**
  * @brief  Enable or disable the INT3 noise filter. 
  * @param  NewState: The INT3 noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFEN3>
  */
void DNF_SetInt3Filter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFEN3 = 1U;
    } else {
        TSB_NF_ENCR_NFEN3 = 0U;
    }
}

/**
  * @brief  Get the INT3 noise filter state. 
  * @param  None
  * @retval The INT3 noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFEN3>
  */
FunctionalState DNF_GetInt3FilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFEN3 == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

/**
  * @brief  Enable or disable the INT4 noise filter. 
  * @param  NewState: The INT4 noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFEN4>
  */
void DNF_SetInt4Filter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFEN4 = 1U;
    } else {
        TSB_NF_ENCR_NFEN4 = 0U;
    }
}

/**
  * @brief  Get the INT4 noise filter state. 
  * @param  None
  * @retval The INT4 noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFEN4>
  */
FunctionalState DNF_GetInt4FilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFEN4 == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

/**
  * @brief  Enable or disable the INT5 noise filter. 
  * @param  NewState: The INT5 noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFEN5>
  */
void DNF_SetInt5Filter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFEN5 = 1U;
    } else {
        TSB_NF_ENCR_NFEN5 = 0U;
    }
}

/**
  * @brief  Get the INT5 noise filter state. 
  * @param  None
  * @retval The INT5 noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFEN5>
  */
FunctionalState DNF_GetInt5FilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFEN5 == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

#ifdef TMPM3V6
/**
  * @brief  Enable or disable the INT6 noise filter. 
  * @param  NewState: The INT6 noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFEN6>
  */
void DNF_SetInt6Filter(volatile FunctionalState NewState)
{

    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFEN6 = 1U;
    } else {
        TSB_NF_ENCR_NFEN6 = 0U;
    }
}

/**
  * @brief  Get the INT6 noise filter state. 
  * @param  None
  * @retval The INT6 noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFEN6>
  */
FunctionalState DNF_GetInt6FilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFEN6 == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

/**
  * @brief  Enable or disable the INT7 noise filter. 
  * @param  NewState: The INT7 noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFEN7>
  */
void DNF_SetInt7Filter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFEN7 = 1U;
    } else {
        TSB_NF_ENCR_NFEN7 = 0U;
    }
}

/**
  * @brief  Get the INT7 noise filter state. 
  * @param  None
  * @retval The INT7 noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFEN7>
  */
FunctionalState DNF_GetInt7FilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFEN7 == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}
#endif

/**
  * @brief  Enable or disable the INT8 noise filter. 
  * @param  NewState: The INT8 noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFEN8>
  */
void DNF_SetInt8Filter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFEN8 = 1U;
    } else {
        TSB_NF_ENCR_NFEN8 = 0U;
    }
}

/**
  * @brief  Get the INT8 noise filter state. 
  * @param  None
  * @retval The INT8 noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFEN8>
  */
FunctionalState DNF_GetInt8FilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFEN8 == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

#ifdef TMPM3V6
/**
  * @brief  Enable or disable the INT9 noise filter. 
  * @param  NewState: The INT9 noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFEN9>
  */
void DNF_SetInt9Filter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFEN9 = 1U;
    } else {
        TSB_NF_ENCR_NFEN9 = 0U;
    }
}

/**
  * @brief  Get the INT9 noise filter state. 
  * @param  None
  * @retval The INT9 noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFEN9>
  */
FunctionalState DNF_GetInt9FilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFEN9 == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

/**
  * @brief  Enable or disable the INTA noise filter. 
  * @param  NewState: The INTA noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFENA>
  */
void DNF_SetIntAFilter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFENA = 1U;
    } else {
        TSB_NF_ENCR_NFENA = 0U;
    }
}

/**
  * @brief  Get the INTA noise filter state. 
  * @param  None
  * @retval The INTA noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFENA>
  */
FunctionalState DNF_GetIntAFilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFENA == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

/**
  * @brief  Enable or disable the INTB noise filter. 
  * @param  NewState: The INTB noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFENB>
  */
void DNF_SetIntBFilter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFENB = 1U;
    } else {
        TSB_NF_ENCR_NFENB = 0U;
    }
}

/**
  * @brief  Get the INTB noise filter state. 
  * @param  None
  * @retval The INTB noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFENB>
  */
FunctionalState DNF_GetIntBFilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFENB == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

/**
  * @brief  Enable or disable the INTC noise filter. 
  * @param  NewState: The INTC noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFENC>
  */
void DNF_SetIntCFilter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFENC = 1U;
    } else {
        TSB_NF_ENCR_NFENC = 0U;
    }
}

/**
  * @brief  Get the INTC noise filter state. 
  * @param  None
  * @retval The INTC noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFENC>
  */
FunctionalState DNF_GetIntCFilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFENC == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

/**
  * @brief  Enable or disable the INTD noise filter. 
  * @param  NewState: The INTD noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFEND>
  */
void DNF_SetIntDFilter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFEND = 1U;
    } else {
        TSB_NF_ENCR_NFEND = 0U;
    }
}

/**
  * @brief  Get the INTD noise filter state. 
  * @param  None
  * @retval The INTD noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFEND>
  */
FunctionalState DNF_GetIntDFilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFEND == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

/**
  * @brief  Enable or disable the INTE noise filter. 
  * @param  NewState: The INTE noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFENE>
  */
void DNF_SetIntEFilter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFENE = 1U;
    } else {
        TSB_NF_ENCR_NFENE = 0U;
    }
}

/**
  * @brief  Get the INTE noise filter state. 
  * @param  None
  * @retval The INTE noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFENE>
  */
FunctionalState DNF_GetIntEFilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFENE == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}
#endif

/**
  * @brief  Enable or disable the INTF noise filter. 
  * @param  NewState: The INTF noise filter state.
  *   This parameter can be one of the following values:
  *   ENABLE, DISABLE.
  * @retval None
  * @register The used register:
  *   NFENCR<NFENF>
  */
void DNF_SetIntFFilter(volatile FunctionalState NewState)
{
    /* Check the parameters */
    assert_param(IS_FUNCTIONAL_STATE(NewState));

    if (NewState == ENABLE) {
        TSB_NF_ENCR_NFENF = 1U;
    } else {
        TSB_NF_ENCR_NFENF = 0U;
    }
}

/**
  * @brief  Get the INTF noise filter state. 
  * @param  None
  * @retval The INTF noise filter state.
  *   The value returned can be one of the following values:
  *   ENABLE, DISABLE.
  * @register The used register:
  *   NFENCR<NFENF>
  */
FunctionalState DNF_GetIntFFilterState(void)
{
    FunctionalState retval = DISABLE;

    if (TSB_NF_ENCR_NFENF == 1U) {
        retval = ENABLE;
    } else {
        /* Do nothing */
    }

    return retval;
}

/** @} */
/* End of group DNF_Exported_Functions */

/** @} */
/* End of group DNF */

/** @} */
/* End of group TX03_Periph_Driver */

#endif                          /* defined(__TMPM3Vx_DNF_H) */
